import { v4 as uuidv4 } from "uuid"
import type { Simulation } from "./debutant"

const examenSimulations: Simulation[] = [
  {
    id: uuidv4(),
    title: "Simulation d'examen officiel",
    description: "Simulation complète dans les conditions réelles de l'examen",
    duration: 40,
    questions: [
      {
        id: uuidv4(),
        question: "Quelle est la vitesse maximale autorisée sur une route à double sens hors agglomération ?",
        options: ["70 km/h", "80 km/h", "90 km/h", "110 km/h"],
        correctAnswer: "80 km/h",
        explanation:
          "Sur une route à double sens hors agglomération, la vitesse maximale autorisée est de 80 km/h (sauf décision contraire de l'autorité locale).",
      },
      {
        id: uuidv4(),
        question: "Quelle est la distance minimale de sécurité à respecter sur autoroute par temps de pluie ?",
        options: ["2 secondes", "3 secondes", "4 secondes", "5 secondes"],
        correctAnswer: "4 secondes",
        explanation:
          "Sur autoroute par temps de pluie, la distance de sécurité minimale doit être doublée par rapport au temps sec, soit 4 secondes au lieu de 2 secondes.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation des feux de brouillard arrière ?",
        options: [
          "Obligatoire par temps de pluie",
          "Autorisée uniquement par brouillard épais ou chute de neige",
          "Obligatoire sur autoroute la nuit",
          "Autorisée en permanence pour être plus visible",
        ],
        correctAnswer: "Autorisée uniquement par brouillard épais ou chute de neige",
        explanation:
          "Les feux de brouillard arrière ne doivent être utilisés que par brouillard épais ou chute de neige. Ils doivent être éteints dès que les conditions de visibilité redeviennent normales car ils sont très éblouissants.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le port de la ceinture de sécurité pour une femme enceinte ?",
        options: [
          "Obligatoire sans exception",
          "Facultatif à partir du 6ème mois",
          "Obligatoire avec certificat médical possible d'exemption",
          "Interdit car dangereux pour le fœtus",
        ],
        correctAnswer: "Obligatoire avec certificat médical possible d'exemption",
        explanation:
          "Le port de la ceinture est obligatoire pour tous, y compris les femmes enceintes. Une exemption est possible uniquement sur présentation d'un certificat médical d'exemption.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation du klaxon en agglomération ?",
        options: [
          "Autorisée en permanence",
          "Autorisée uniquement de jour",
          "Autorisée uniquement en cas de danger immédiat",
          "Interdite dans tous les cas",
        ],
        correctAnswer: "Autorisée uniquement en cas de danger immédiat",
        explanation:
          "En agglomération, l'usage du klaxon n'est autorisé qu'en cas de danger immédiat. Il est interdit de l'utiliser pour manifester son impatience ou son mécontentement.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le dépassement d'un cycliste hors agglomération ?",
        options: [
          "Laisser 0,5 mètre d'écart latéral",
          "Laisser 1 mètre d'écart latéral",
          "Laisser 1,5 mètre d'écart latéral",
          "Attendre d'être sur une autre voie",
        ],
        correctAnswer: "Laisser 1,5 mètre d'écart latéral",
        explanation:
          "Hors agglomération, il faut laisser un écart latéral d'au moins 1,5 mètre pour dépasser un cycliste. En agglomération, cet écart doit être d'au moins 1 mètre.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le stationnement sur un emplacement réservé aux livraisons ?",
        options: [
          "Autorisé en dehors des heures de livraison",
          "Autorisé la nuit et le week-end",
          "Interdit sauf pour les véhicules de livraison",
          "Autorisé pour une durée maximale de 15 minutes",
        ],
        correctAnswer: "Interdit sauf pour les véhicules de livraison",
        explanation:
          "Le stationnement sur un emplacement réservé aux livraisons est interdit sauf pour les véhicules de livraison, et uniquement pendant le temps nécessaire aux opérations de chargement et déchargement.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation des feux de position seuls ?",
        options: [
          "Autorisée de nuit en agglomération bien éclairée",
          "Autorisée de jour par temps de brouillard",
          "Interdite dans tous les cas",
          "Obligatoire à l'arrêt moteur tournant",
        ],
        correctAnswer: "Interdite dans tous les cas",
        explanation:
          "L'utilisation des feux de position seuls est interdite en circulation. De nuit ou par mauvaise visibilité, il faut utiliser au minimum les feux de croisement.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le transport d'enfants à l'avant du véhicule ?",
        options: [
          "Interdit pour les enfants de moins de 10 ans",
          "Autorisé avec un dispositif adapté",
          "Interdit dans tous les cas",
          "Autorisé uniquement à partir de 12 ans",
        ],
        correctAnswer: "Autorisé avec un dispositif adapté",
        explanation:
          "Le transport d'enfants à l'avant est autorisé à condition d'utiliser un dispositif de retenue adapté à leur taille et à leur poids (siège auto, rehausseur). Il est toutefois recommandé de privilégier les places arrière.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation des feux de détresse sur autoroute ?",
        options: [
          "Obligatoire en cas de ralentissement brusque",
          "Facultative même en cas de panne",
          "Obligatoire uniquement la nuit",
          "Interdite sauf en cas d'accident",
        ],
        correctAnswer: "Obligatoire en cas de ralentissement brusque",
        explanation:
          "Sur autoroute, l'utilisation des feux de détresse est obligatoire en cas de ralentissement brusque pour prévenir les véhicules qui suivent et éviter un sur-accident.",
      },
    ],
  },
]

export default examenSimulations
